@@ -8,14 +8,17 @@ import jsii
 import publication
 import typing_extensions
 
+import aws_cdk.aws_ec2._jsii
+import aws_cdk.aws_s3._jsii
+import aws_cdk.aws_s3_assets._jsii
 import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/aws-route53resolver",
-    "1.119.0",
+    "1.121.0",
     __name__[0:-6],
-    "aws-route53resolver@1.119.0.jsii.tgz",
+    "aws-route53resolver@1.121.0.jsii.tgz",
 )
 
 __all__ = [
